
# [Protocol Buffers](https://developers.google.com/protocol-buffers)

Source:

https://github.com/wpscott/AcFunDanmaku/tree/master/AcFunDanmu/protos

Tool:

https://github.com/protocolbuffers/protobuf/releases/


Tutorials:

https://developers.google.com/protocol-buffers/docs/tutorials
